# Generated by Django 4.1.1 on 2022-12-04 11:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('menu', '0002_menugroup_kind'),
    ]

    operations = [
        migrations.AddField(
            model_name='menu',
            name='is_new',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='menu',
            name='link',
            field=models.CharField(blank=True, default='#', max_length=255),
        ),
    ]
