# Generated by Django 4.1.1 on 2023-01-26 14:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('menu', '0004_alter_menu_menu_group'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='menugroup',
            name='site',
        ),
        migrations.AddField(
            model_name='menugroup',
            name='group',
            field=models.OneToOneField(default=None, on_delete=django.db.models.deletion.CASCADE, to='auth.group'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='menugroup',
            name='level',
            field=models.SmallIntegerField(default=0),
        ),
    ]
