# Generated by Django 4.1.1 on 2023-01-26 15:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('auth', '0012_alter_user_first_name_max_length'),
        ('menu', '0005_remove_menugroup_site_menugroup_group_and_more'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='menugrouptranslation',
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name='menugrouptranslation',
            name='master',
        ),
        migrations.AddField(
            model_name='menugroup',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='sites.site'),
        ),
        migrations.AlterField(
            model_name='menugroup',
            name='group',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.group'),
        ),
        migrations.DeleteModel(
            name='MenuCustom',
        ),
        migrations.DeleteModel(
            name='MenuGroupTranslation',
        ),
    ]
