# Generated by Django 4.1.1 on 2023-01-30 11:41

from django.db import migrations
from menu.auto_insert_group import create_groups

class Migration(migrations.Migration):

    dependencies = [
        ('menu', '0006_alter_menugrouptranslation_unique_together_and_more'),
    ]

    operations = [
        migrations.RunPython(create_groups)
    ]
