# Generated by Django 4.1.1 on 2022-11-25 09:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('menu', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='menugroup',
            name='kind',
            field=models.SmallIntegerField(choices=[(1, 'Frontend'), (2, 'Backend')], default=1),
        ),
    ]
